package opmanager

import (
	"context"
	"fmt"
	"testing"
)

var apiUrl string = "https://opmanager.itsm.love:8061"
var apiKey string = "2d1be4ad58afabc0f99b55343b483d8b"

func TestLoadPaginatedDataFromOpManager(t *testing.T) {
	client, err := New(Config{
		Verbose:              true,
		ApiUrl:               apiUrl,
		ApiKey:               apiKey,
		UseProxy:             0,
		IgnoreSslCertificate: 1,
		PollingInterval:      60,
	})

	client.ctx = context.Background()

	if err != nil {
		t.Fatal(err)
	}

	var dst PaginateResponse[Device]

	params := map[string]string{"sortByColumn": "deviceName", "sortByType": "asc"}
	allResults, err := get(client, "/api/json/v2/device/listDevices", params, 10, 1, &dst)

	if err != nil {
		t.Fatal(err)
	}

	if len(allResults.Rows) == 0 {
		t.Fatal("OpManager did not return any records")
	}

}

func TestLoadPaginateDataFromOpManagerWithError(t *testing.T) {
	client, err := New(Config{
		Verbose:              true,
		ApiUrl:               apiUrl,
		ApiKey:               apiKey,
		UseProxy:             0,
		IgnoreSslCertificate: 1,
		PollingInterval:      60,
	})

	client.ctx = context.Background()

	if err != nil {
		t.Fatal(err)
	}

	var dst PaginateResponse[Device]

	params := map[string]string{"foobar": "this should be an error"}
	_, err = get(client, "/api/json/v2/device/listDevices", params, 10, 1, &dst)

	if err.Error() != "Irrelevant parameter found in the request." {
		t.Fatal("API returned an unexpected error or nothing")
		fmt.Println(err)
	}

}
